import React from "react";
import { Tooltip, Typography, useTheme } from "@material-ui/core";
import {
  Brightness1,
  Cancel,
  Error,
  RadioButtonUnchecked,
  ErrorOutline,
  HelpOutline,
  PlayCircleFilled,
  PauseCircleFilled
} from "@material-ui/icons";
import Popover from "../../common/Popover";
import AlertMessages from "../AlertMessages/AlertMessages";

function AlertMessagesPopoverContents({ title, alerts }) {
  // for now filter out links on alerts due to issues with
  // focus behavior of popovers
  const alertsWithoutLinks = (alerts || []).map((alert) => ({
    ...alert,
    link: undefined
  }));

  return (
    <div>
      <Typography
        style={{
          fontWeight: alertsWithoutLinks.length > 0 ? "bold" : "normal"
        }}
      >
        {title}
      </Typography>
      {alertsWithoutLinks.length > 0 ? (
        <AlertMessages alerts={alertsWithoutLinks} />
      ) : null}
    </div>
  );
}

export function IOCStatusIcon({ ioc }) {
  const theme = useTheme();
  let { active, alerts, activeDeployment, id } = ioc;
  const alertSeverity = ioc?.alertSeverity?.toLowerCase();

  const iconConfig = {
    active: {
      title: "Active",
      icon: <Brightness1 title="Active" />
    },
    disabled: {
      title: "Disabled",
      icon: <Cancel title="Disabled" />
    },
    alert: {
      title: "Alert",
      icon: <Error title="Alert" />
    },
    inactive: {
      title: "Inactive",
      icon: <RadioButtonUnchecked title="Inactive" />
    },
    "inactive alert": {
      title: "Alert",
      icon: <ErrorOutline title="Active" />
    },
    null: {
      title: "Unknown",
      icon: <HelpOutline title="Unknown" />
    }
  };

  let status = null;

  if (active === null) active = undefined;

  if (active && (alertSeverity === undefined || alertSeverity === "info")) {
    // Active status / running
    status = "active";
  } else if (
    active === false &&
    (alertSeverity === undefined || alertSeverity === "info")
  ) {
    // stopped/paused
    status = "disabled";
  } else if (
    active !== undefined &&
    alertSeverity !== undefined &&
    alertSeverity !== "info"
  ) {
    // warning/error
    status = "alert";
  } else if (
    (active === undefined || activeDeployment === null) &&
    (alertSeverity === undefined || alertSeverity === "info")
  ) {
    // Inactive status
    status = "inactive";
  } else if (
    (active === undefined || activeDeployment === null) &&
    alertSeverity !== undefined &&
    alertSeverity !== "info"
  ) {
    // inactive with warning/error
    status = "inactive alert";
  } else {
    // unknown fallback state
    status = null;
  }

  const iconTitle = iconConfig[status].title;
  const statusIcon = iconConfig[status].icon;

  return (
    <div>
      <Popover
        id={`ioc-status-popover-${id}`}
        renderOwningComponent={({
          ariaOwns,
          ariaHasPopup,
          handlePopoverOpen,
          handlePopoverClose
        }) => (
          <div
            aria-owns={ariaOwns}
            aria-haspopup={ariaHasPopup}
            onMouseEnter={handlePopoverOpen}
            onMouseLeave={handlePopoverClose}
            style={{ color: theme.palette.status.icons }}
          >
            {statusIcon}
          </div>
        )}
        popoverContents={
          <AlertMessagesPopoverContents
            title={iconTitle}
            alerts={alerts}
          />
        }
        anchorOrigin={{
          vertical: "top",
          horizontal: "right"
        }}
      />
    </div>
  );
}

export function CommandTypeIcon({ type, colorStyle = "colors" }) {
  const theme = useTheme();

  const commandTypeColors = {
    start: theme.palette.status.ok,
    stop: theme.palette.status.fail
  };

  const commandTypeBlack = {
    start: theme.palette.status.icons,
    stop: theme.palette.status.icons
  };

  const colorConfig = {
    black: commandTypeBlack,
    colors: commandTypeColors
  };

  const commandTypeIcons = {
    start: {
      title: "Set to active",
      icon: <PlayCircleFilled />
    },
    stop: {
      title: "Set to inactive",
      icon: <PauseCircleFilled />
    }
  };

  const iconStyle = { fill: colorConfig[colorStyle][type.toLowerCase()] };
  const iconTitle = commandTypeIcons[type.toLowerCase()].title;
  const statusIcon = commandTypeIcons[type.toLowerCase()].icon;

  return (
    <Tooltip
      title={iconTitle}
      style={iconStyle}
    >
      {statusIcon}
    </Tooltip>
  );
}
