import React, { useEffect, useCallback, useState } from "react";
import { useRecordSearch } from "../../api/SwaggerApi";
import { initRequestParams } from "../common/Helper";
import { RecordTable } from "./RecordTable";
import { SearchBar } from "../common/SearchBar/SearchBar";
import useUrlState from "@ahooksjs/use-url-state";
import { serialize, deserialize } from "../common/URLState/URLState";
import { Grid, Tabs, Tab, Typography } from "@material-ui/core";

export function RecordSearch({ iocName, rowType }) {
  const [records, getRecords /* reset*/, , loading] = useRecordSearch();
  const [state, setState] = useUrlState(
    {
      record_tab: "0",
      rows: "20",
      page: "0",
      query: ""
    },
    { navigateMode: "replace" }
  );
  const [recordFilter, setRecordFilter] = useState();

  const handleTabChange = useCallback(
    (event, tab) => {
      setState((s) =>
        serialize(s.record_tab) === serialize(tab)
          ? { record_tab: serialize(tab) }
          : { record_tab: serialize(tab), page: "0" }
      );

      changeTab(tab);
    },
    [setState]
  );

  useEffect(() => {
    state.record_tab && changeTab(deserialize(state.record_tab));
  }, [state]);

  const changeTab = (tab) => {
    if (tab === 0) {
      setRecordFilter(null);
    } else if (tab === 1) {
      setRecordFilter("ACTIVE");
    } else if (tab === 2) {
      setRecordFilter("INACTIVE");
    }
  };

  const lazyParams = useCallback(() => {
    return {
      rows: deserialize(state.rows),
      page: deserialize(state.page)
    };
  }, [state]);

  const setLazyParams = useCallback(
    (params) => {
      setState({ rows: serialize(params.rows), page: serialize(params.page) });
    },
    [setState]
  );

  const rowsPerPage = [20, 50];

  useEffect(() => {
    let requestParams = initRequestParams(lazyParams());
    const query = deserialize(state.query);
    if (query && query.length > 0) {
      requestParams = {
        ...requestParams,
        record_name: "*" + query + "*"
      };
    }
    if (iocName && iocName.length > 0) {
      requestParams = {
        ...requestParams,
        ioc_name: iocName
      };
    }
    requestParams.pv_status = recordFilter;

    getRecords(requestParams);
  }, [getRecords, lazyParams, iocName, state, recordFilter]);

  const setSearch = useCallback(
    (query) => {
      setState({ query: serialize(query) });
    },
    [setState]
  );

  return (
    <Grid
      container
      spacing={1}
    >
      <Grid item>
        <Tabs
          value={deserialize(state.record_tab)}
          onChange={handleTabChange}
          indicatorColor="primary"
          textColor="primary"
        >
          <Tab label={<Typography variant="h5">All</Typography>} />
          <Tab label={<Typography variant="h5">Only active</Typography>} />
          <Tab label={<Typography variant="h5">Only inactive</Typography>} />
        </Tabs>
      </Grid>
      <Grid item>
        <SearchBar
          search={setSearch}
          query={deserialize(state.query)}
          loading={loading}
          placeholder="Search in Record"
        >
          <RecordTable
            records={records}
            rowType={rowType}
            loading={loading}
            lazyParams={lazyParams()}
            setLazyParams={setLazyParams}
            rowsPerPage={rowsPerPage}
          />
        </SearchBar>
      </Grid>
    </Grid>
  );
}
