import React from "react";
import {
  Paper,
  Grid,
  useTheme,
  makeStyles,
  Typography
} from "@material-ui/core";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { RootContainer } from "../../components/common/Container/RootContainer";
import ActiveIOCChart from "../../components/statistics/ActiveIOCChart";
import DeploymentLineChart from "../../components/statistics/DeploymentLineChart";
import {
  useActiveIOCHistory,
  useDeploymenStatistics
} from "../../api/SwaggerApi";
import { HostStatistics } from "../../components/statistics/HostStatistics";
import { IOCStatistics } from "../../components/statistics/IOCStatistics";
import OperationChart from "../../components/statistics/OperationChart/OperationChart";

const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(4)
  }
}));

export function StatisticsView() {
  const classes = useStyles();

  const title = "Statistics";
  useGlobalAppBar(title);

  const theme = useTheme();

  return (
    <RootContainer>
      <Grid
        container
        spacing={theme.spacing(0.5)}
      >
        <Grid
          item
          xs={12}
        >
          <Typography variant="h2">Statistics</Typography>
        </Grid>

        <Grid
          item
          xs={6}
        >
          <IOCStatistics />
        </Grid>

        <Grid
          item
          xs={6}
        >
          <HostStatistics />
        </Grid>

        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <OperationChart
              title="Operations over time"
              hook={useDeploymenStatistics}
            />
          </Paper>
        </Grid>
        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <ActiveIOCChart title="Number of IOCs detected per network" />
          </Paper>
        </Grid>
        <Grid
          item
          xs={12}
        >
          <Paper className={classes.paper}>
            <DeploymentLineChart
              title="Number of IOCs detected over time"
              chartLabel="Active IOCs over time"
              hook={useActiveIOCHistory}
            />
          </Paper>
        </Grid>
      </Grid>
    </RootContainer>
  );
}
